.. _Preferences:

Preferences
-----------

This preferences contains information on contact and general technological details. All of them can be changed from
:ref:`AdminPanel`.

.. tabularcolumns:: |p{4cm}|p{3.5cm}|p{9cm}|
.. list-table::
   :header-rows: 1

   * - Name
     - Default value
     - Description
     
   * - Skype
     - myskype
     -  
     
   * - Email [#f1]_
     - myemail@email.com
     -  
     
   * - Phone number
     - 000 000 000 00 00
     -  
     
   * - Turn on/off REST Api
     - True
     -  
     
   * - Max number of inner pages [#f2]_
     - 3
     - Number of pages that can be shown under main menu when users follow links inside page.
     
   * - Google Analytic code
     - 000000 
     -   
     
   * - Image quality
     - 70 
     - Global setting for the quality of the uploaded pictures. Picture quality is in the direct proportion to the size of the file. A value of 100 corresponds to the maximum quality.
     
   * - Image autoscale
     - True 
     - Global setting for autoscaling of the uploaded pictures if its *width>333px*. Pictures will be scaled to *width=333px*.

   * - Theme
     - modern
     - Choose a theme for the switch
  
.. rubric:: Footnotes

.. [#f1] E-mail is automatically converted to the image for protection against spam bots.
.. [#f2] Number of pages of type **inner page** may be infinitely.

.. seealso:: :ref:`technical_configuration`.
